pygeodesy.ellipsoids.Ellipsoid

Package pygeodesy :: Module ellipsoids :: Class Ellipsoid |
[frames] | no frames]

# Class Ellipsoid

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
    named._NamedEnumItem --+
                           |
                          Ellipsoid

Known Subclasses:
  - Ellipsoid2

Ellipsoid with equatorial and polar radii, flattening, inverse flattening and other, often used, cached attributes, supporting oblate and prolate ellipsoidal and spherical earth models.

Instance Methods
__init__(self, a, b=None, f_=None, f=None, **name) New Ellipsoid from the equatorial radius and either the polar radius or inverse flattening or flattening. |
__eq__(self, other) Compare this and an other ellipsoid. |
__hash__(self) hash(x) |
auxAuthalic(self, lat, inverse=False) Compute the authalic auxiliary latitude (Xi) or the inverse thereof. |
auxConformal(self, lat, inverse=False) Compute the conformal auxiliary latitude (Chi) or the inverse thereof. |
auxGeocentric(self, lat, inverse=False, height=0.0) Compute the geocentric auxiliary latitude (Theta) or the inverse thereof. |
auxIsometric(self, lat, inverse=False) Compute the isometric auxiliary latitude (Psi) or the inverse thereof. |
auxParametric(self, lat, inverse=False) Compute the parametric auxiliary latitude (Beta) or the inverse thereof. |
auxReduced(self, lat, inverse=False) Compute the parametric auxiliary latitude (Beta) or the inverse thereof. |
auxRectifying(self, lat, inverse=False) Compute the rectifying auxiliary latitude (Mu) or the inverse thereof. |
circle4(self, lat) Get the equatorial or a parallel circle of latitude. |
degrees2m(self, deg, lat=0) Convert an angle along the equator or along a parallel of (geodetic) latitude to the distance. |
distance2(self, lat0, lon0, lat1, lon1) Approximate the distance and (initial) bearing between two points based on the local, flat earth approximation aka Hubeny formula. |
ecef(self, Ecef=None) Return ECEF converter. |
e2s(self, s) Compute norm sqrt(1 - e2 * s**2). |
e2s2(self, s) Compute 1 - e2 * s**2. |
es_atanh(self, x) Compute es * atanh(es * x) or -es * atan(es * x) for oblate respectively prolate ellipsoids where es is the signed (1st) eccentricity. |
es_tauf(self, taup) Compute Karney's equations (19), (20) and (21). |
es_taupf(self, tau) Compute Karney's equations (7), (8) and (9). |
geodesic_(self, exact=True) Get the an exact `Geodesic...` instance for this ellipsoid. |
hartzell4(self, pov, los=None) Compute the intersection of this ellipsoid's surface and a Line-Of-Sight from a Point-Of-View in space. |
height4(self, xyz, normal=True) Compute the projection on and the height of a cartesian above or below this ellipsoid's surface. |
Llat(self, lat) Return the meridional length, the distance along a meridian between the equator and a (geodetic) latitude, see `L`. |
Lmeridian(self, lat) Return the meridional length, the distance along a meridian between the equator and a (geodetic) latitude, see `L`. |
m2degrees(self, distance, lat=0) Convert a distance to an angle along the equator or along a parallel of (geodetic) latitude. |
m2radians(self, distance, lat=0) Convert a distance to an angle along the equator or along a parallel of (geodetic) latitude. |
radians2m(self, rad, lat=0) Convert an angle to the distance along the equator or along a parallel of (geodetic) latitude. |
Rgeocentric(self, lat) Compute the geocentric earth radius of (geodetic) latitude. |
rhumb_(self, exact=True) Get the an exact `Rhumb...` instance for this ellipsoid. |
Rlat(self, lat) Approximate the earth radius of (geodetic) latitude. |
roc1_(self, sa, ca=None) Compute the prime-vertical, normal radius of curvature of (geodetic) latitude, unscaled. |
roc2(self, lat, scaled=False) Compute the meridional and prime-vertical, normal radii of curvature of (geodetic) latitude. |
roc2_(self, phi, scaled=False) Compute the meridional and prime-vertical, normal radii of curvature of (geodetic) latitude. |
rocAzimuth(self, lat, azimuth) Compute the directional radius of curvature of (geodetic) latitude and `azimuth` compass direction. |
rocBearing(self, lat, bearing) Compute the directional radius of curvature of (geodetic) latitude and `bearing` compass direction. |
rocGauss(self, lat) Compute the Gaussian radius of curvature of (geodetic) latitude. |
rocMean(self, lat) Compute the mean radius of curvature of (geodetic) latitude. |
rocMeridional(self, lat) Compute the meridional radius of curvature of (geodetic) latitude. |
rocPrimeVertical(self, lat) Compute the prime-vertical, normal radius of curvature of (geodetic) latitude, aka the transverse radius of curvature. |
rocTransverse(self, lat) Compute the prime-vertical, normal radius of curvature of (geodetic) latitude, aka the transverse radius of curvature. |
toEllipse(self, **name) Get this ellipsoid's meridional ellipse Ellipse. |
toEllipsoid2(self, **name) Get a copy of this ellipsoid as an Ellipsoid2. |
toStr(self, prec=8, terse=4, **sep_name) Return this ellipsoid as a text string. |
toTriaxial(self, **name) Convert this ellipsoid to a Triaxial_. |
Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| a Get the equatorial radius, semi-axis (`meter`).
| a2 Get the equatorial radius squared (`meter` squared), a**2.
| a2_ Get the inverse of the equatorial radius squared (`meter` squared), 1 / a**2.
| a_b Get the ratio equatorial over polar radius (`float`), a / b == 1 / (1 - f).
| a2_b Get the polar meridional (or polar) radius of curvature (`meter`), a**2 / b.
| a2_b2 Get the ratio equatorial over polar radius squared (`float`), (a / b)**2 == 1 / (1 - e**2) == 1 / (1 - e2) == 1 / e21.
| a_f Get the equatorial radius and flattening (a_f2Tuple), see method `toEllipsoid2`.
| a_f2 Get the equatorial radius and flattening (a_f2Tuple), see method `toEllipsoid2`.
| A Get the UTM meridional (or rectifying) radius (`meter`).
| AlphaKs Get the Krüger Alpha series coefficients (`KsOrder``-tuple`).
| area Get the ellipsoid's surface area (`meter` squared), 4 * PI * c2.
| areax Get the ellipsoid's surface area (`meter` squared), 4 * PI * c2x, more accurate for very oblate ellipsoids.
| b Get the polar radius, semi-axis (`meter`).
| b_a Get the ratio polar over equatorial radius (`float`), b / a == f1 == 1 - f.
| b2 Get the polar radius squared (`float`), b**2.
| b2_a Get the equatorial meridional radius of curvature (`meter`), b**2 / a, see `rocMeridional``(0)`.
| b2_a2 Get the ratio polar over equatorial radius squared (`float`), (b / a)**2 == (1 - f)**2 == 1 - e**2 == `e21`.
| BetaKs Get the Krüger Beta series coefficients (`KsOrder``-tuple`).
| c DEPRECATED, use property `R2` or `Rauthalic`.
| c2 Get the authalic earth radius squared (`meter` squared).
| c2x Get the authalic earth radius squared (`meter` squared), more accurate for very oblate ellipsoids.
| e Get the unsigned, (1st) eccentricity (`float`), sqrt(1 - (b / a)**2)), see `a_b2e`.
| e12 DEPRECATED, use property `e21`.
| e2 Get the signed, (1st) eccentricity squared (`float`), f * (2 - f) == 1 - (b / a)**2, see `a_b2e2`.
| e2abs Get the unsigned, (1st) eccentricity squared (`float`).
| e21 Get 1 less 1st eccentricity squared (`float`), 1 - e**2 == 1 - e2 == (1 - f)**2 == b**2 / a**2, see `b2_a2`.
| e22 Get the signed, 2nd eccentricity squared (`float`), e2 / (1 - e2) == e2 / (1 - f)**2 == (a / b)**2 - 1, see `a_b2e22`.
| e22abs Get the unsigned, 2nd eccentricity squared (`float`).
| e32 Get the signed, 3rd eccentricity squared (`float`), e2 / (2 - e2) == (a**2 - b**2) / (a**2 + b**2), see `a_b2e32`.
| e32abs Get the unsigned, 3rd eccentricity squared (`float`).
| e4 Get the unsignd, (1st) eccentricity to 4th power (`float`), e**4 == e2**2.
| eccentricity Get the unsigned, (1st) eccentricity (`float`), sqrt(1 - (b / a)**2)), see `a_b2e`.
| eccentricity1st2 Get the signed, (1st) eccentricity squared (`float`), f * (2 - f) == 1 - (b / a)**2, see `a_b2e2`.
| eccentricity2nd2 Get the signed, 2nd eccentricity squared (`float`), e2 / (1 - e2) == e2 / (1 - f)**2 == (a / b)**2 - 1, see `a_b2e22`.
| eccentricity3rd2 Get the signed, 3rd eccentricity squared (`float`), e2 / (2 - e2) == (a**2 - b**2) / (a**2 + b**2), see `a_b2e32`.
| equatoradius Get the equatorial radius, semi-axis (`meter`).
| equatorimeter Get the ellipsoid's equatorial perimeter (`meter`).
| es Get the signed (1st) eccentricity (`float`).
| es_c Get (1 - f) * exp(es_atanh(1)) (`float`), b_a * exp(es_atanh(1)).
| f Get the flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate.
| f_ Get the inverse flattening (`scalar`), 1 / f == a / (a - b), `0` for spherical, see `a_b2f_`.
| f1 Get the 1 - flattening (`float`), f1 == 1 - f == b / a.
| f2 Get the 2nd flattening (`float`), (a - b) / b == f / (1 - f), `0` for spherical, see `a_b2f2`.
| geodesic DEPRECATED, use property `geodesicw`.
| geodesicw Get this ellipsoid's wrapped geodesicw.Geodesic, provided Karney's geographiclib package is installed.
| geodesicx Get this ellipsoid's exact GeodesicExact.
| geodsolve Get this ellipsoid's GeodesicSolve, the wrapper around utility GeodSolve, provided the path to the `GeodSolve` executable is specified with env variable `PYGEODESY_GEODSOLVE` or re-/set with this property..
| isEllipsoidal Is this model ellipsoidal (`bool`)?
| isOblate Is this ellipsoid oblate (`bool`)? Prolate or spherical otherwise.
| isProlate Is this ellipsoid prolate (`bool`)? Oblate or spherical otherwise.
| isSpherical Is this ellipsoid spherical (`bool`)?
| KsOrder Class `property` with a `.name` attribute.
| L Get the quarter meridian `L`, aka the `polar distance` along a meridian between the equator and a pole (`meter`), b * Elliptic(-e2 / (1 - e2)).cE or b * PI / 2.
| majoradius DEPRECATED, use property `a` or `Requatorial`.
| minoradius DEPRECATED, use property `b`, `polaradius` or `Rpolar`.
| n Get the 3rd flattening (`float`), f / (2 - f) == (a - b) / (a + b), see `a_b2n`.
| flattening Get the flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate.
| flattening1st Get the flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate.
| flattening2nd Get the 2nd flattening (`float`), (a - b) / b == f / (1 - f), `0` for spherical, see `a_b2f2`.
| flattening3rd Get the 3rd flattening (`float`), f / (2 - f) == (a - b) / (a + b), see `a_b2n`.
| polaradius Get the polar radius, semi-axis (`meter`).
| polarimeter Get the ellipsoid's polar, meridional perimeter (`meter`).
| quarteradius DEPRECATED, use property `L` or method `Llat`.
| R1 Get the mean earth radius per IUGG (`meter`), (2 * a + b) / 3 == a * (1 - f / 3).
| Rmean Get the mean earth radius per IUGG (`meter`), (2 * a + b) / 3 == a * (1 - f / 3).
| R2 Get the authalic earth radius (`meter`), sqrt(c2).
| Rauthalic Get the authalic earth radius (`meter`), sqrt(c2).
| R2x Get the authalic earth radius (`meter`), sqrt(c2x).
| Rauthalicx Get the authalic earth radius (`meter`), sqrt(c2x).
| R3 Get the volumetric earth radius (`meter`), (a * a * b)**(1/3).
| Rvolumetric Get the volumetric earth radius (`meter`), (a * a * b)**(1/3).
| Rbiaxial Get the biaxial, quadratic mean earth radius (`meter`), sqrt((a**2 + b**2) / 2).
| Requatorial Get the equatorial radius, semi-axis (`meter`).
| Rgeometric Get the geometric mean earth radius (`meter`), sqrt(a * b).
| rhumbaux Get this ellipsoid's Auxiliary `rhumb.RhumbAux`.
| rhumbekx Get this ellipsoid's Elliptic, Krüger `rhumb.Rhumb`.
| rhumbsolve Get this ellipsoid's RhumbSolve, the wrapper around utility RhumbSolve, provided the path to the `RhumbSolve` executable is specified with env variable `PYGEODESY_RHUMBSOLVE` or re-/set with this property.
| rhumbx DEPRECATED on 2023.11.28, use property `rhumbekx`.
| Rpolar Get the polar radius, semi-axis (`meter`).
| rocEquatorial2 Get the meridional and prime-vertical, normal radii of curvature at the equator as Curvature2Tuple`(meridional, prime_vertical)`.
| rocPolar Get the polar meridional (or polar) radius of curvature (`meter`), a**2 / b.
| Rquadratic DEPRECATED, use property `Rbiaxial` or `Rtriaxial`.
| Rr DEPRECATED, use property `Rrectifying`.
| Rrectifying Get the rectifying earth radius (`meter`), ((a**(3/2) + b**(3/2)) / 2)**(2/3).
| Rs DEPRECATED, use property `Rgeometric`.
| Rtriaxial Get the triaxial, quadratic mean earth radius (`meter`), sqrt((3 * a**2 + b**2) / 4).
| volume Get the ellipsoid's volume (`meter**3`), 4 / 3 * PI * R3**3.
Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, a, b=None, f_=None, f=None, **name) (Constructor) |
New Ellipsoid from the equatorial radius and either the polar radius or inverse flattening or flattening. Arguments: `a` - Equatorial radius, semi-axis (`meter`). `b` - Optional polar radius, semi-axis (`meter`). `f_` - Inverse flattening: a / (a - b) (`float` >>> 1.0). `f` - Flattening: (a - b) / a (`scalar`, near zero for spherical). `name` - Optional, unique `name=NN` (`str`). Raises: `NameError` - Ellipsoid with the same `name` already exists. `ValueError` - Invalid `a`, `b`, `f_` or `f` or `f_` and `f` are incompatible. Overrides: object.__init__ Note: abs(f_) > 1 / EPS or abs(1 / f_) < EPS is forced to 1 / f_ = 0, spherical.

### __eq__ (self, other) (Equality operator) |
Compare this and an other ellipsoid. Arguments: `other` - The other ellipsoid (Ellipsoid or Ellipsoid2). Returns: `True` if equal, `False` otherwise.

### __hash__ (self) (Hashing function) |
hash(x) Overrides: object.__hash__ (inherited documentation)

### auxAuthalic (self, lat, inverse=False) |
Compute the authalic auxiliary latitude (Xi) or the inverse thereof. Arguments: `lat` - The geodetic (or authalic) latitude (`degrees90`). `inverse` - If `True`, `lat` is the authalic and return the geodetic latitude (`bool`). Returns: The authalic (or geodetic) latitude in `degrees90`. See Also: Inverse-/AuthalicLatitude, Authalic latitude, and Snyder, p 16.

### auxConformal (self, lat, inverse=False) |
Compute the conformal auxiliary latitude (Chi) or the inverse thereof. Arguments: `lat` - The geodetic (or conformal) latitude (`degrees90`). `inverse` - If `True`, `lat` is the conformal and return the geodetic latitude (`bool`). Returns: The conformal (or geodetic) latitude in `degrees90`. See Also: Inverse-/ConformalLatitude, Conformal latitude, and Snyder, pp 15-16.

### auxGeocentric (self, lat, inverse=False, height=0.0) |
Compute the geocentric auxiliary latitude (Theta) or the inverse thereof. Arguments: `lat` - The geodetic (or geocentric) latitude (`degrees90`). `inverse` - If `True`, `lat` is the geocentric and return the geocentric latitude (`bool`). `height` - Optional, ellipsoidal height (`meter`). Returns: The geocentric (or geodetic) latitude in `degrees90`. See Also: Inverse-/GeocentricLatitude, Geocentric latitude, and Snyder, pp 17-18.

### auxIsometric (self, lat, inverse=False) |
Compute the isometric auxiliary latitude (Psi) or the inverse thereof. Arguments: `lat` - The geodetic (or isometric) latitude (`degrees`). `inverse` - If `True`, `lat` is the isometric and return the geodetic latitude (`bool`). Returns: The isometric (or geodetic) latitude in `degrees`. Note: The isometric latitude for geodetic `+/-90` is far outside the `[-90..+90]` range but the inverse thereof is the original geodetic latitude. See Also: Inverse-/IsometricLatitude, Isometric latitude, and Snyder, pp 15-16.

### auxParametric (self, lat, inverse=False) |
Compute the parametric auxiliary latitude (Beta) or the inverse thereof. Arguments: `lat` - The geodetic (or parametric) latitude (`degrees90`). `inverse` - If `True`, `lat` is the parametric and return the geodetic latitude (`bool`). Returns: The parametric (or geodetic) latitude in `degrees90`. See Also: Inverse-/ParametricLatitude, Parametric latitude, and Snyder, p 18.

### auxReduced (self, lat, inverse=False) |
Compute the parametric auxiliary latitude (Beta) or the inverse thereof. Arguments: `lat` - The geodetic (or parametric) latitude (`degrees90`). `inverse` - If `True`, `lat` is the parametric and return the geodetic latitude (`bool`). Returns: The parametric (or geodetic) latitude in `degrees90`. See Also: Inverse-/ParametricLatitude, Parametric latitude, and Snyder, p 18.

### auxRectifying (self, lat, inverse=False) |
Compute the rectifying auxiliary latitude (Mu) or the inverse thereof. Arguments: `lat` - The geodetic (or rectifying) latitude (`degrees90`). `inverse` - If `True`, `lat` is the rectifying and return the geodetic latitude (`bool`). Returns: The rectifying (or geodetic) latitude in `degrees90`. See Also: Inverse-/RectifyingLatitude, Rectifying latitude, and Snyder, pp 16-17.

### circle4 (self, lat) |
Get the equatorial or a parallel circle of latitude. Arguments: `lat` - Geodetic latitude (`degrees90`, `str`). Returns: A Circle4Tuple`(radius, height, lat, beta)`. Raises: `RangeError` - Latitude `lat` outside valid range and rangerrors is `True`. `TypeError` - Invalid `lat`. `ValueError` - Invalid `lat`. See Also: Definition of p and z under Parametric (or reduced) latitude, Karney's C++ CircleRadius and CircleHeight and method `Rlat`.

### degrees2m (self, deg, lat=0) |
Convert an angle along the equator or along a parallel of (geodetic) latitude to the distance. Arguments: `deg` - The angle (`degrees`). `lat` - Parallel latitude (`degrees90`, `str`). Returns: Distance (`meter`, same units as the equatorial and polar radii) or `0` for near-polar `lat`. Raises: `RangeError` - Latitude `lat` outside valid range and rangerrors is `True`. `ValueError` - Invalid `deg` or `lat`.

### distance2 (self, lat0, lon0, lat1, lon1) |
Approximate the distance and (initial) bearing between two points based on the local, flat earth approximation aka Hubeny formula. Suitable only for distances of several hundred Km or Miles and only between points not near-polar. Arguments: `lat0` - From latitude (`degrees`). `lon0` - From longitude (`degrees`). `lat1` - To latitude (`degrees`). `lon1` - To longitude (`degrees`). Returns: A Distance2Tuple`(distance, initial)` with `distance` in same units as this ellipsoid's axes. Note: The meridional and prime_vertical radii of curvature are taken and scaled at the initial latitude, see `roc2`. See Also: Function pygeodesy.flatLocal/pygeodesy.hubeny.

### ecef (self, Ecef=None) |
Return ECEF converter. Arguments: `Ecef` - ECEF class to use, default EcefKarney. Returns: An ECEF converter for this `ellipsoid`. Raises: `TypeError` - Invalid `Ecef`. See Also: Module pygeodesy.ecef.

### e2s (self, s) |
Compute norm sqrt(1 - e2 * s**2). Arguments: `s` - Sine value (`scalar`). Returns: Norm (`float`). Raises: `ValueError` - Invalid `s`.

### e2s2 (self, s) |
Compute 1 - e2 * s**2. Arguments: `s` - Sine value (`scalar`). Returns: Result (`float`). Raises: `ValueError` - Invalid `s`.

### es_atanh (self, x) |
Compute es * atanh(es * x) or -es * atan(es * x) for oblate respectively prolate ellipsoids where es is the signed (1st) eccentricity. Raises: `ValueError` - Invalid `x`. See Also: Function Math::eatanhe.

### es_tauf (self, taup) |
Compute Karney's equations (19), (20) and (21). See Also: Karney's C++ method Math::tauf and and Veness' JavaScript method toLatLon.

### es_taupf (self, tau) |
Compute Karney's equations (7), (8) and (9). See Also: Karney's C++ method Math::taupf.

### geodesic_ (self, exact=True) |
Get the an exact `Geodesic...` instance for this ellipsoid. Arguments: `exact` - If `bool` return GeodesicExact`(exact=exact, ...)`, otherwise a Geodesic, GeodesicExact or GeodesicSolve instance for this ellipsoid. Returns: The `exact` geodesic (`Geodesic...`). Raises: `TypeError` - Invalid `exact`. `ValueError` - Incompatible `exact` ellipsoid.

### hartzell4 (self, pov, los=None) |
Compute the intersection of this ellipsoid's surface and a Line-Of-Sight from a Point-Of-View in space. Arguments: `pov` - Point-Of-View outside this ellipsoid (`Cartesian`, Ecef9Tuple or Vector3d). `los` - Line-Of-Sight, direction to this ellipsoid (Los, Vector3d) or `True` for the normal, perpendicular, plumb to the surface of this ellipsoid or `False` or `None` to point to its center. Returns: Vector4Tuple`(x, y, z, h)` with the cartesian coordinates `x`, `y` and `z` of the projection on or the intersection with this ellipsoid and the distance `h` from `pov` to `(x, y, z)` along `los`, all in `meter`, conventionally. Raises: `IntersectionError` - Null `pov` or `los` vector, or `pov` is inside this ellipsoid or `los` points outside this ellipsoid or in opposite direction. `TypeError` - Invalid `pov` or `los`. See Also: Satellite Line-of-Sight Intersection with Earth and methods Ellipsoid.height4 and Triaxial.hartzell4.

### height4 (self, xyz, normal=True) |
Compute the projection on and the height of a cartesian above or below this ellipsoid's surface. Arguments: `xyz` - The cartesian (`Cartesian`, Ecef9Tuple, Vector3d, Vector3Tuple or Vector4Tuple). `normal` - If `True`, the projection is perpendicular to (the nearest point on) this ellipsoid's surface, otherwise the `radial` line to this ellipsoid's center (`bool`). Returns: Vector4Tuple`(x, y, z, h)` with the cartesian coordinates `x`, `y` and `z` of the projection on and the height `h` above or below this ellipsoid's surface, all in `meter`, conventionally. Raises: `ValueError` - Null `xyz`. `TypeError` - Non-cartesian `xyz`. See Also: Distance to and intersection with an ellipse and methods Ellipsoid.hartzell4 and Triaxial.height4.

### Llat (self, lat) |
Return the meridional length, the distance along a meridian between the equator and a (geodetic) latitude, see `L`. Arguments: `lat` - Geodetic latitude (`degrees90`). Returns: The meridional length at `lat`, negative on southern hemisphere (`meter`).

### Lmeridian (self, lat) |
Return the meridional length, the distance along a meridian between the equator and a (geodetic) latitude, see `L`. Arguments: `lat` - Geodetic latitude (`degrees90`). Returns: The meridional length at `lat`, negative on southern hemisphere (`meter`).

### m2degrees (self, distance, lat=0) |
Convert a distance to an angle along the equator or along a parallel of (geodetic) latitude. Arguments: `distance` - Distance (`meter`). `lat` - Parallel latitude (`degrees90`, `str`). Returns: Angle (`degrees`) or `INF` for near-polar `lat`. Raises: `RangeError` - Latitude `lat` outside valid range and rangerrors is `True`. `ValueError` - Invalid `distance` or `lat`.

### m2radians (self, distance, lat=0) |
Convert a distance to an angle along the equator or along a parallel of (geodetic) latitude. Arguments: `distance` - Distance (`meter`). `lat` - Parallel latitude (`degrees90`, `str`). Returns: Angle (`radians`) or `INF` for near-polar `lat`. Raises: `RangeError` - Latitude `lat` outside valid range and rangerrors is `True`. `ValueError` - Invalid `distance` or `lat`.

### radians2m (self, rad, lat=0) |
Convert an angle to the distance along the equator or along a parallel of (geodetic) latitude. Arguments: `rad` - The angle (`radians`). `lat` - Parallel latitude (`degrees90`, `str`). Returns: Distance (`meter`, same units as the equatorial and polar radii) or `0` for near-polar `lat`. Raises: `RangeError` - Latitude `lat` outside valid range and rangerrors is `True`. `ValueError` - Invalid `rad` or `lat`.

### Rgeocentric (self, lat) |
Compute the geocentric earth radius of (geodetic) latitude. Arguments: `lat` - Latitude (`degrees90`). Returns: Geocentric earth radius (`meter`). Raises: `ValueError` - Invalid `lat`. See Also: Geocentric Radius

### rhumb_ (self, exact=True) |
Get the an exact `Rhumb...` instance for this ellipsoid. Arguments: `exact` - If `bool` or `None` return Rhumb`(exact=exact, ...)`, otherwise a Rhumb, RhumbAux or RhumbSolve instance for this ellipsoid. Returns: The `exact` rhumb (`Rhumb...`). Raises: `TypeError` - Invalid `exact`. `ValueError` - Incompatible `exact` ellipsoid.

### Rlat (self, lat) |
Approximate the earth radius of (geodetic) latitude. Arguments: `lat` - Latitude (`degrees90`). Returns: Approximate earth radius (`meter`). Raises: `RangeError` - Latitude `lat` outside valid range and rangerrors is `True`. `TypeError` - Invalid `lat`. `ValueError` - Invalid `lat`. Note: `Rlat(90)` equals `Rpolar`. See Also: Method `circle4`.

### roc1_ (self, sa, ca=None) |
Compute the prime-vertical, normal radius of curvature of (geodetic) latitude, unscaled. Arguments: `sa` - Sine of the latitude (`float`, [-1.0..+1.0]). `ca` - Optional cosine of the latitude (`float`, [-1.0..+1.0]) to use an alternate formula. Returns: The prime-vertical radius of curvature (`float`). Note: The delta between both formulae with `Ellipsoids.WGS84` is less than 2 nanometer over the entire latitude range. See Also: Method roc2_ and class EcefYou.

### roc2 (self, lat, scaled=False) |
Compute the meridional and prime-vertical, normal radii of curvature of (geodetic) latitude. Arguments: `lat` - Latitude (`degrees90`). `scaled` - Scale prime_vertical by `cos(radians(lat))` (`bool`). Returns: An Curvature2Tuple`(meridional, prime_vertical)` with the radii of curvature. Raises: `ValueError` - Invalid `lat`. See Also: Methods roc2_ and roc1_, Local, flat earth approximation and meridional and prime vertical Radii of Curvature.

### roc2_ (self, phi, scaled=False) |
Compute the meridional and prime-vertical, normal radii of curvature of (geodetic) latitude. Arguments: `phi` - Latitude (`radians`). `scaled` - Scale prime_vertical by `cos(phi)` (`bool`). Returns: An Curvature2Tuple`(meridional, prime_vertical)` with the radii of curvature. Raises: `ValueError` - Invalid `phi`. See Also: Methods roc2 and roc1_, property rocEquatorial2, Local, flat earth approximation and the meridional and prime vertical Radii of Curvature.

### rocAzimuth (self, lat, azimuth) |
Compute the directional radius of curvature of (geodetic) latitude and `azimuth` compass direction. See Also: Method rocBearing for details, using `azimuth` for `bearing`.

### rocBearing (self, lat, bearing) |
Compute the directional radius of curvature of (geodetic) latitude and `bearing` compass direction. Arguments: `lat` - Latitude (`degrees90`). `bearing` - Direction (compass `degrees360`). Returns: Directional radius of curvature (`meter`). Raises: `RangeError` - Latitude `lat` outside valid range and rangerrors is `True`. `ValueError` - Invalid `lat` or `bearing`. See Also: Radii of Curvature

### rocGauss (self, lat) |
Compute the Gaussian radius of curvature of (geodetic) latitude. Arguments: `lat` - Latitude (`degrees90`). Returns: Gaussian radius of curvature (`meter`). Raises: `ValueError` - Invalid `lat`. See Also: Non-directional Radii of Curvature

### rocMean (self, lat) |
Compute the mean radius of curvature of (geodetic) latitude. Arguments: `lat` - Latitude (`degrees90`). Returns: Mean radius of curvature (`meter`). Raises: `ValueError` - Invalid `lat`. See Also: Non-directional Radii of Curvature

### rocMeridional (self, lat) |
Compute the meridional radius of curvature of (geodetic) latitude. Arguments: `lat` - Latitude (`degrees90`). Returns: Meridional radius of curvature (`meter`). Raises: `ValueError` - Invalid `lat`. See Also: Methods roc2 and roc2_, Local, flat earth approximation and Radii of Curvature.

### rocPrimeVertical (self, lat) |
Compute the prime-vertical, normal radius of curvature of (geodetic) latitude, aka the transverse radius of curvature. Arguments: `lat` - Latitude (`degrees90`). Returns: Prime-vertical radius of curvature (`meter`). Raises: `ValueError` - Invalid `lat`. See Also: Methods roc2, roc2_ and roc1_, Local, flat earth approximation and Radii of Curvature.

### rocTransverse (self, lat) |
Compute the prime-vertical, normal radius of curvature of (geodetic) latitude, aka the transverse radius of curvature. Arguments: `lat` - Latitude (`degrees90`). Returns: Prime-vertical radius of curvature (`meter`). Raises: `ValueError` - Invalid `lat`. See Also: Methods roc2, roc2_ and roc1_, Local, flat earth approximation and Radii of Curvature.

### toEllipse (self, **name) |
Get this ellipsoid's meridional ellipse Ellipse. Arguments: `name` - Optional, unique `name=NN` (`str`).

### toEllipsoid2 (self, **name) |
Get a copy of this ellipsoid as an Ellipsoid2. Arguments: `name` - Optional, unique `name=NN` (`str`). See Also: Property `a_f`.

### toStr (self, prec=8, terse=4, **sep_name) |
Return this ellipsoid as a text string. Arguments: `prec` - Number of decimal digits, unstripped (`int`). `terse` - Limit the number of items (`int`, 0...18), use `terse=0` or `=None` for all. `sep_name` - Optional `name=NN` (`str`) or `None` to exclude this ellipsoid's name and separator `sep=", "` to join the items (`str`). Returns: This `Ellipsoid`'s attributes (`str`). Overrides: named._Named.toStr

### toTriaxial (self, **name) |
Convert this ellipsoid to a Triaxial_. Arguments: `name` - Optional `name=NN` (`str`). Returns: A Triaxial_ or Triaxial with the `X` axis pointing east and `Z` pointing north. See Also: Method Triaxial_.toEllipsoid.

Property Details

### a Get the equatorial radius, semi-axis (`meter`). Get method: a(self) - Get the equatorial radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### a2 Get the equatorial radius squared (`meter` squared), a**2. Get method: a2(self) - Get the equatorial radius squared (`meter` squared), a**2. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### a2_ Get the inverse of the equatorial radius squared (`meter` squared), 1 / a**2. Get method: a2_(self) - Get the inverse of the equatorial radius squared (`meter` squared), 1 / a**2. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### a_b Get the ratio equatorial over polar radius (`float`), a / b == 1 / (1 - f). Get method: a_b(self) - Get the ratio equatorial over polar radius (`float`), a / b == 1 / (1 - f). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### a2_b Get the polar meridional (or polar) radius of curvature (`meter`), a**2 / b. Get method: a2_b(self) - Get the polar meridional (or polar) radius of curvature (`meter`), a**2 / b. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Radii of Curvature and Moritz, H. (1980), Geodetic Reference System 1980. Note: Symbol `c` is used by IUGG and IERS for the polar radius of curvature, see c2 and R2 or Rauthalic.

### a2_b2 Get the ratio equatorial over polar radius squared (`float`), (a / b)**2 == 1 / (1 - e**2) == 1 / (1 - e2) == 1 / e21. Get method: a2_b2(self) - Get the ratio equatorial over polar radius squared (`float`), (a / b)**2 == 1 / (1 - e**2) == 1 / (1 - e2) == 1 / e21. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### a_f Get the equatorial radius and flattening (a_f2Tuple), see method `toEllipsoid2`. Get method: a_f(self) - Get the equatorial radius and flattening (a_f2Tuple), see method `toEllipsoid2`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### a_f2 Get the equatorial radius and flattening (a_f2Tuple), see method `toEllipsoid2`. Get method: a_f(self) - Get the equatorial radius and flattening (a_f2Tuple), see method `toEllipsoid2`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### A Get the UTM meridional (or rectifying) radius (`meter`). Get method: A(self) - Get the UTM meridional (or rectifying) radius (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. Note: `A * PI / 2` ≈= L, the quarter meridian. See Also: Meridian arc unit Q, the mean, meridional length per radian.

### AlphaKs Get the Krüger Alpha series coefficients (`KsOrder``-tuple`). Get method: AlphaKs(self) - Get the Krüger Alpha series coefficients (`KsOrder``-tuple`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### area Get the ellipsoid's surface area (`meter` squared), 4 * PI * c2. Get method: area(self) - Get the ellipsoid's surface area (`meter` squared), 4 * PI * c2. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Properties areax, c2 and R2 and functions ellipsoidalExact.areaOf and ellipsoidalKarney.areaOf.

### areax Get the ellipsoid's surface area (`meter` squared), 4 * PI * c2x, more accurate for very oblate ellipsoids. Get method: areax(self) - Get the ellipsoid's surface area (`meter` squared), 4 * PI * c2x, more accurate for very oblate ellipsoids. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Properties area, c2x and R2x, class GeodesicExact and functions ellipsoidalExact.areaOf and ellipsoidalKarney.areaOf.

### b Get the polar radius, semi-axis (`meter`). Get method: b(self) - Get the polar radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### b_a Get the ratio polar over equatorial radius (`float`), b / a == f1 == 1 - f. Get method: b_a(self) - Get the ratio polar over equatorial radius (`float`), b / a == f1 == 1 - f. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Property f1.

### b2 Get the polar radius squared (`float`), b**2. Get method: b2(self) - Get the polar radius squared (`float`), b**2. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### b2_a Get the equatorial meridional radius of curvature (`meter`), b**2 / a, see `rocMeridional``(0)`. Get method: b2_a(self) - Get the equatorial meridional radius of curvature (`meter`), b**2 / a, see `rocMeridional``(0)`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Radii of Curvature.

### b2_a2 Get the ratio polar over equatorial radius squared (`float`), (b / a)**2 == (1 - f)**2 == 1 - e**2 == `e21`. Get method: b2_a2(self) - Get the ratio polar over equatorial radius squared (`float`), (b / a)**2 == (1 - f)**2 == 1 - e**2 == `e21`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### BetaKs Get the Krüger Beta series coefficients (`KsOrder``-tuple`). Get method: BetaKs(self) - Get the Krüger Beta series coefficients (`KsOrder``-tuple`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### c DEPRECATED, use property `R2` or `Rauthalic`. Get method: c(self) - DEPRECATED, use property `R2` or `Rauthalic`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### c2 Get the authalic earth radius squared (`meter` squared). Get method: c2(self) - Get the authalic earth radius squared (`meter` squared). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Properties c2x, area, R2, Rauthalic, Karney's equation (60) and C++ Ellipsoid.Area, Authalic radius, Surface area and surface area.

### c2x Get the authalic earth radius squared (`meter` squared), more accurate for very oblate ellipsoids. Get method: c2x(self) - Get the authalic earth radius squared (`meter` squared), more accurate for very oblate ellipsoids. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Properties c2, areax, R2x, Rauthalicx, class GeodesicExact and Karney's comments at C++ attribute GeodesicExact._c2.

### e Get the unsigned, (1st) eccentricity (`float`), sqrt(1 - (b / a)**2)), see `a_b2e`. Get method: e(self) - Get the unsigned, (1st) eccentricity (`float`), sqrt(1 - (b / a)**2)), see `a_b2e`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Property es.

### e12 DEPRECATED, use property `e21`. Get method: e12(self) - DEPRECATED, use property `e21`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### e2 Get the signed, (1st) eccentricity squared (`float`), f * (2 - f) == 1 - (b / a)**2, see `a_b2e2`. Get method: e2(self) - Get the signed, (1st) eccentricity squared (`float`), f * (2 - f) == 1 - (b / a)**2, see `a_b2e2`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### e2abs Get the unsigned, (1st) eccentricity squared (`float`). Get method: e2abs(self) - Get the unsigned, (1st) eccentricity squared (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### e21 Get 1 less 1st eccentricity squared (`float`), 1 - e**2 == 1 - e2 == (1 - f)**2 == b**2 / a**2, see `b2_a2`. Get method: e21(self) - Get 1 less 1st eccentricity squared (`float`), 1 - e**2 == 1 - e2 == (1 - f)**2 == b**2 / a**2, see `b2_a2`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### e22 Get the signed, 2nd eccentricity squared (`float`), e2 / (1 - e2) == e2 / (1 - f)**2 == (a / b)**2 - 1, see `a_b2e22`. Get method: e22(self) - Get the signed, 2nd eccentricity squared (`float`), e2 / (1 - e2) == e2 / (1 - f)**2 == (a / b)**2 - 1, see `a_b2e22`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### e22abs Get the unsigned, 2nd eccentricity squared (`float`). Get method: e22abs(self) - Get the unsigned, 2nd eccentricity squared (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### e32 Get the signed, 3rd eccentricity squared (`float`), e2 / (2 - e2) == (a**2 - b**2) / (a**2 + b**2), see `a_b2e32`. Get method: e32(self) - Get the signed, 3rd eccentricity squared (`float`), e2 / (2 - e2) == (a**2 - b**2) / (a**2 + b**2), see `a_b2e32`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### e32abs Get the unsigned, 3rd eccentricity squared (`float`). Get method: e32abs(self) - Get the unsigned, 3rd eccentricity squared (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### e4 Get the unsignd, (1st) eccentricity to 4th power (`float`), e**4 == e2**2. Get method: e4(self) - Get the unsignd, (1st) eccentricity to 4th power (`float`), e**4 == e2**2. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### eccentricity Get the unsigned, (1st) eccentricity (`float`), sqrt(1 - (b / a)**2)), see `a_b2e`. Get method: e(self) - Get the unsigned, (1st) eccentricity (`float`), sqrt(1 - (b / a)**2)), see `a_b2e`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Property es.

### eccentricity1st2 Get the signed, (1st) eccentricity squared (`float`), f * (2 - f) == 1 - (b / a)**2, see `a_b2e2`. Get method: e2(self) - Get the signed, (1st) eccentricity squared (`float`), f * (2 - f) == 1 - (b / a)**2, see `a_b2e2`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### eccentricity2nd2 Get the signed, 2nd eccentricity squared (`float`), e2 / (1 - e2) == e2 / (1 - f)**2 == (a / b)**2 - 1, see `a_b2e22`. Get method: e22(self) - Get the signed, 2nd eccentricity squared (`float`), e2 / (1 - e2) == e2 / (1 - f)**2 == (a / b)**2 - 1, see `a_b2e22`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### eccentricity3rd2 Get the signed, 3rd eccentricity squared (`float`), e2 / (2 - e2) == (a**2 - b**2) / (a**2 + b**2), see `a_b2e32`. Get method: e32(self) - Get the signed, 3rd eccentricity squared (`float`), e2 / (2 - e2) == (a**2 - b**2) / (a**2 + b**2), see `a_b2e32`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### equatoradius Get the equatorial radius, semi-axis (`meter`). Get method: a(self) - Get the equatorial radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### equatorimeter Get the ellipsoid's equatorial perimeter (`meter`). Get method: equatorimeter(self) - Get the ellipsoid's equatorial perimeter (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### es Get the signed (1st) eccentricity (`float`). Get method: es(self) - Get the signed (1st) eccentricity (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Property e.

### es_c Get (1 - f) * exp(es_atanh(1)) (`float`), b_a * exp(es_atanh(1)). Get method: es_c(self) - Get (1 - f) * exp(es_atanh(1)) (`float`), b_a * exp(es_atanh(1)). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### f Get the flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate. Get method: f(self) - Get the flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### f_ Get the inverse flattening (`scalar`), 1 / f == a / (a - b), `0` for spherical, see `a_b2f_`. Get method: f_(self) - Get the inverse flattening (`scalar`), 1 / f == a / (a - b), `0` for spherical, see `a_b2f_`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### f1 Get the 1 - flattening (`float`), f1 == 1 - f == b / a. Get method: f1(self) - Get the 1 - flattening (`float`), f1 == 1 - f == b / a. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Property b_a.

### f2 Get the 2nd flattening (`float`), (a - b) / b == f / (1 - f), `0` for spherical, see `a_b2f2`. Get method: f2(self) - Get the 2nd flattening (`float`), (a - b) / b == f / (1 - f), `0` for spherical, see `a_b2f2`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### geodesic DEPRECATED, use property `geodesicw`. Get method: geodesic(self) - DEPRECATED, use property `geodesicw`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### geodesicw Get this ellipsoid's wrapped geodesicw.Geodesic, provided Karney's geographiclib package is installed. Get method: geodesicw(self) - Get this ellipsoid's wrapped geodesicw.Geodesic, provided Karney's geographiclib package is installed. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### geodesicx Get this ellipsoid's exact GeodesicExact. Get method: geodesicx(self) - Get this ellipsoid's exact GeodesicExact. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### geodsolve Get this ellipsoid's GeodesicSolve, the wrapper around utility GeodSolve, provided the path to the `GeodSolve` executable is specified with env variable `PYGEODESY_GEODSOLVE` or re-/set with this property.. Get method: geodsolve(self) - Get this ellipsoid's GeodesicSolve, the wrapper around utility GeodSolve, provided the path to the `GeodSolve` executable is specified with env variable `PYGEODESY_GEODSOLVE` or re-/set with this property.. Set method: geodsolve(self, path) - Re-/set the (fully qualified) path to the GeodSolve executable, overriding env variable `PYGEODESY_GEODSOLVE` (`str`).

### isEllipsoidal Is this model ellipsoidal (`bool`)? Get method: isEllipsoidal(self) - Is this model ellipsoidal (`bool`)? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isOblate Is this ellipsoid oblate (`bool`)? Prolate or spherical otherwise. Get method: isOblate(self) - Is this ellipsoid oblate (`bool`)? Prolate or spherical otherwise. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isProlate Is this ellipsoid prolate (`bool`)? Oblate or spherical otherwise. Get method: isProlate(self) - Is this ellipsoid prolate (`bool`)? Oblate or spherical otherwise. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isSpherical Is this ellipsoid spherical (`bool`)? Get method: isSpherical(self) - Is this ellipsoid spherical (`bool`)? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### KsOrder Class `property` with a `.name` attribute. Get method: KsOrder(self) - Get the Krüger series' order (`int` 4, 6 or 8). Set method: KsOrder(self, order) - Set the Krüger series' order (`int` 4, 6 or 8).

### L Get the quarter meridian `L`, aka the `polar distance` along a meridian between the equator and a pole (`meter`), b * Elliptic(-e2 / (1 - e2)).cE or b * PI / 2. Get method: L(self) - Get the quarter meridian `L`, aka the `polar distance` along a meridian between the equator and a pole (`meter`), b * Elliptic(-e2 / (1 - e2)).cE or b * PI / 2. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### majoradius DEPRECATED, use property `a` or `Requatorial`. Get method: majoradius(self) - DEPRECATED, use property `a` or `Requatorial`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### minoradius DEPRECATED, use property `b`, `polaradius` or `Rpolar`. Get method: minoradius(self) - DEPRECATED, use property `b`, `polaradius` or `Rpolar`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### n Get the 3rd flattening (`float`), f / (2 - f) == (a - b) / (a + b), see `a_b2n`. Get method: n(self) - Get the 3rd flattening (`float`), f / (2 - f) == (a - b) / (a + b), see `a_b2n`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### flattening Get the flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate. Get method: f(self) - Get the flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### flattening1st Get the flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate. Get method: f(self) - Get the flattening (`scalar`), (a - b) / a, `0` for spherical, negative for prolate. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### flattening2nd Get the 2nd flattening (`float`), (a - b) / b == f / (1 - f), `0` for spherical, see `a_b2f2`. Get method: f2(self) - Get the 2nd flattening (`float`), (a - b) / b == f / (1 - f), `0` for spherical, see `a_b2f2`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### flattening3rd Get the 3rd flattening (`float`), f / (2 - f) == (a - b) / (a + b), see `a_b2n`. Get method: n(self) - Get the 3rd flattening (`float`), f / (2 - f) == (a - b) / (a + b), see `a_b2n`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### polaradius Get the polar radius, semi-axis (`meter`). Get method: b(self) - Get the polar radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### polarimeter Get the ellipsoid's polar, meridional perimeter (`meter`). Get method: polarimeter(self) - Get the ellipsoid's polar, meridional perimeter (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### quarteradius DEPRECATED, use property `L` or method `Llat`. Get method: quarteradius(self) - DEPRECATED, use property `L` or method `Llat`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### R1 Get the mean earth radius per IUGG (`meter`), (2 * a + b) / 3 == a * (1 - f / 3). Get method: R1(self) - Get the mean earth radius per IUGG (`meter`), (2 * a + b) / 3 == a * (1 - f / 3). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Earth radius and method `Rgeometric`.

### Rmean Get the mean earth radius per IUGG (`meter`), (2 * a + b) / 3 == a * (1 - f / 3). Get method: R1(self) - Get the mean earth radius per IUGG (`meter`), (2 * a + b) / 3 == a * (1 - f / 3). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Earth radius and method `Rgeometric`.

### R2 Get the authalic earth radius (`meter`), sqrt(c2). Get method: R2(self) - Get the authalic earth radius (`meter`), sqrt(c2). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: `R2x`, `c2`, `area` and Earth radius.

### Rauthalic Get the authalic earth radius (`meter`), sqrt(c2). Get method: R2(self) - Get the authalic earth radius (`meter`), sqrt(c2). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: `R2x`, `c2`, `area` and Earth radius.

### R2x Get the authalic earth radius (`meter`), sqrt(c2x). Get method: R2x(self) - Get the authalic earth radius (`meter`), sqrt(c2x). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: `R2`, `c2x` and `areax`.

### Rauthalicx Get the authalic earth radius (`meter`), sqrt(c2x). Get method: R2x(self) - Get the authalic earth radius (`meter`), sqrt(c2x). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: `R2`, `c2x` and `areax`.

### R3 Get the volumetric earth radius (`meter`), (a * a * b)**(1/3). Get method: R3(self) - Get the volumetric earth radius (`meter`), (a * a * b)**(1/3). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Earth radius and `volume`.

### Rvolumetric Get the volumetric earth radius (`meter`), (a * a * b)**(1/3). Get method: R3(self) - Get the volumetric earth radius (`meter`), (a * a * b)**(1/3). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Earth radius and `volume`.

### Rbiaxial Get the biaxial, quadratic mean earth radius (`meter`), sqrt((a**2 + b**2) / 2). Get method: Rbiaxial(self) - Get the biaxial, quadratic mean earth radius (`meter`), sqrt((a**2 + b**2) / 2). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: `Rtriaxial`

### Requatorial Get the equatorial radius, semi-axis (`meter`). Get method: a(self) - Get the equatorial radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### Rgeometric Get the geometric mean earth radius (`meter`), sqrt(a * b). Get method: Rgeometric(self) - Get the geometric mean earth radius (`meter`), sqrt(a * b). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: `R1`.

### rhumbaux Get this ellipsoid's Auxiliary `rhumb.RhumbAux`. Get method: rhumbaux(self) - Get this ellipsoid's Auxiliary `rhumb.RhumbAux`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### rhumbekx Get this ellipsoid's Elliptic, Krüger `rhumb.Rhumb`. Get method: rhumbekx(self) - Get this ellipsoid's Elliptic, Krüger `rhumb.Rhumb`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### rhumbsolve Get this ellipsoid's RhumbSolve, the wrapper around utility RhumbSolve, provided the path to the `RhumbSolve` executable is specified with env variable `PYGEODESY_RHUMBSOLVE` or re-/set with this property. Get method: rhumbsolve(self) - Get this ellipsoid's RhumbSolve, the wrapper around utility RhumbSolve, provided the path to the `RhumbSolve` executable is specified with env variable `PYGEODESY_RHUMBSOLVE` or re-/set with this property. Set method: rhumbsolve(self, path) - Re-/set the (fully qualified) path to the RhumbSolve executable, overriding env variable `PYGEODESY_RHUMBSOLVE` (`str`).

### rhumbx DEPRECATED on 2023.11.28, use property `rhumbekx`. Get method: rhumbx(self) - DEPRECATED on 2023.11.28, use property `rhumbekx`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### Rpolar Get the polar radius, semi-axis (`meter`). Get method: b(self) - Get the polar radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### rocEquatorial2 Get the meridional and prime-vertical, normal radii of curvature at the equator as Curvature2Tuple`(meridional, prime_vertical)`. Get method: rocEquatorial2(self) - Get the meridional and prime-vertical, normal radii of curvature at the equator as Curvature2Tuple`(meridional, prime_vertical)`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Methods rocMeridional and rocPrimeVertical, properties b2_a, a2_b, `rocPolar` and polar and equatorial Radii of Curvature.

### rocPolar Get the polar meridional (or polar) radius of curvature (`meter`), a**2 / b. Get method: a2_b(self) - Get the polar meridional (or polar) radius of curvature (`meter`), a**2 / b. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Radii of Curvature and Moritz, H. (1980), Geodetic Reference System 1980. Note: Symbol `c` is used by IUGG and IERS for the polar radius of curvature, see c2 and R2 or Rauthalic.

### Rquadratic DEPRECATED, use property `Rbiaxial` or `Rtriaxial`. Get method: Rquadratic(self) - DEPRECATED, use property `Rbiaxial` or `Rtriaxial`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### Rr DEPRECATED, use property `Rrectifying`. Get method: Rr(self) - DEPRECATED, use property `Rrectifying`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### Rrectifying Get the rectifying earth radius (`meter`), ((a**(3/2) + b**(3/2)) / 2)**(2/3). Get method: Rrectifying(self) - Get the rectifying earth radius (`meter`), ((a**(3/2) + b**(3/2)) / 2)**(2/3). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: Earth radius.

### Rs DEPRECATED, use property `Rgeometric`. Get method: Rs(self) - DEPRECATED, use property `Rgeometric`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### Rtriaxial Get the triaxial, quadratic mean earth radius (`meter`), sqrt((3 * a**2 + b**2) / 4). Get method: Rtriaxial(self) - Get the triaxial, quadratic mean earth radius (`meter`), sqrt((3 * a**2 + b**2) / 4). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: `Rbiaxial`

### volume Get the ellipsoid's volume (`meter**3`), 4 / 3 * PI * R3**3. Get method: volume(self) - Get the ellipsoid's volume (`meter**3`), 4 / 3 * PI * R3**3. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. See Also: `R3`.